==> freecad_0.11.4446-dfsg.orig.tar.gz: FreeCAD-0.11.4446/src/Mod/Complete/Gui/Resources/translations/Complete_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location/>
      <source>Complete</source>
      <translation>完成</translation>
    </message>
    <message>
      <location/>
      <source>Constraint Axle...</source>
      <translation>约束轴...</translation>
    </message>
    <message>
      <location/>
      <source>set a axle constraint between two objects</source>
      <translation>两个对象之间设置轴约束</translation>
    </message>
  </context>
  <context>
    <name>CompleteGui::Workbench</name>
    <message>
      <location/>
      <source>&amp;File</source>
      <translation>文件(&amp;F)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Edit</source>
      <translation>编辑(&amp;E)</translation>
    </message>
    <message>
      <location/>
      <source>Standard views</source>
      <translation>标准视图</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Stereo</source>
      <translation>三维成像(&amp;S)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Zoom</source>
      <translation>缩放(&amp;Z)</translation>
    </message>
    <message>
      <location/>
      <source>Visibility</source>
      <translation>可见性</translation>
    </message>
    <message>
      <location/>
      <source>&amp;View</source>
      <translation>视图(&amp;V)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Tools</source>
      <translation>工具(&amp;T)</translation>
    </message>
    <message>
      <location/>
      <source>Analyze</source>
      <translation>分析</translation>
    </message>
    <message>
      <location/>
      <source>Boolean</source>
      <translation>布尔运算</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Meshes</source>
      <translation>网格(&amp;M)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Part</source>
      <translation>零件(&amp;P)</translation>
    </message>
    <message>
      <location/>
      <source>Parametric</source>
      <translation>参数化</translation>
    </message>
    <message>
      <location/>
      <source>Ske&amp;tch</source>
      <translation>草图(&amp;T)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Drawing</source>
      <translation>绘图(&amp;D)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Raytracing</source>
      <translation>光线追踪(&amp;R)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Drafting</source>
      <translation>绘图(&amp;D)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Windows</source>
      <translation>窗口(&amp;W)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Online-help</source>
      <translation>联机帮助(&amp;O)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Help</source>
      <translation>帮助(&amp;H)</translation>
    </message>
    <message>
      <location/>
      <source>File</source>
      <translation>文件</translation>
    </message>
    <message>
      <location/>
      <source>Macro</source>
      <translation>宏</translation>
    </message>
    <message>
      <location/>
      <source>View</source>
      <translation>视图</translation>
    </message>
    <message>
      <location/>
      <source>Part design</source>
      <translation>零件设计</translation>
    </message>
    <message>
      <location/>
      <source>Sketch based</source>
      <translation>基于草绘</translation>
    </message>
    <message>
      <location/>
      <source>Drawings</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>光线追踪</translation>
    </message>
    <message>
      <location/>
      <source>Drafting</source>
      <translation>绘图</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location/>
      <source>&amp;File</source>
      <translation>文件(&amp;F)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Edit</source>
      <translation>编辑(&amp;E)</translation>
    </message>
    <message>
      <location/>
      <source>Standard views</source>
      <translation>标准视图</translation>
    </message>
    <message>
      <location/>
      <source>&amp;3D View</source>
      <translation>&amp;3D视图</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Zoom</source>
      <translation>缩放(&amp;Z)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;View</source>
      <translation>视图(&amp;V)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Tools</source>
      <translation>工具(&amp;T)</translation>
    </message>
    <message>
      <location/>
      <source>Analyze</source>
      <translation>分析</translation>
    </message>
    <message>
      <location/>
      <source>Boolean</source>
      <translation>布尔运算</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Meshes</source>
      <translation>网格(&amp;M)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Part</source>
      <translation>零件(&amp;P)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Drawing</source>
      <translation>绘图(&amp;D)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Windows</source>
      <translation>窗口(&amp;W)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Online-help</source>
      <translation>联机帮助(&amp;O)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Help</source>
      <translation>帮助(&amp;H)</translation>
    </message>
    <message>
      <location/>
      <source>File</source>
      <translation>文件</translation>
    </message>
    <message>
      <location/>
      <source>Macro</source>
      <translation>宏</translation>
    </message>
    <message>
      <location/>
      <source>View</source>
      <translation>视图</translation>
    </message>
    <message>
      <location/>
      <source>Ske&amp;tch</source>
      <translation>草图(&amp;T)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Raytracing</source>
      <translation>光线追踪(&amp;R)</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Drafting</source>
      <translation>绘图(&amp;D)</translation>
    </message>
    <message>
      <location/>
      <source>Sketch based</source>
      <translation>基于草绘</translation>
    </message>
    <message>
      <location/>
      <source>Parametric</source>
      <translation>参数化</translation>
    </message>
  </context>
</TS>

==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Mod/Complete/Gui/Resources/translations/Complete_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>全部</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>约束轴...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>两对象间设置轴约束</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>自检...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>运行自检测试程序是否正常工作</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>&amp;Drawing</source>
      <translation>图纸(&amp;D)</translation>
    </message>
    <message>
      <source>Ske&amp;tch</source>
      <translation>草绘(&amp;T)</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>光线追踪(&amp;R)</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>绘图(&amp;D)</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>基于草绘</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>参数化</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>对象外观</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>线框工具</translation>
    </message>
  </context>
</TS>
